<?php

namespace Clientes\Cliente\Http\Controllers;

use App\Http\Controllers\AdminWebController as AdminController;
use Form;
use Clientes\Cliente\Http\Requests\ClienteAdminWebRequest;
use Clientes\Cliente\Interfaces\ClienteRepositoryInterface;
use Clientes\Cliente\Models\Cliente;

/**
 * Admin web controller class.
 */
class ClienteAdminWebController extends AdminController
{
    /**
     * Initialize cliente controller.
     *
     * @param type ClienteRepositoryInterface $cliente
     *
     * @return type
     */
    public function __construct(ClienteRepositoryInterface $cliente)
    {
        $this->repository = $cliente;
        parent::__construct();
    }

    /**
     * Display a list of cliente.
     *
     * @return Response
     */
    public function index(ClienteAdminWebRequest $request)
    {
        if ($request->wantsJson()) {
            $clientes  = $this->repository->setPresenter('\\Clientes\\Cliente\\Repositories\\Presenter\\ClienteListPresenter')
                                                ->scopeQuery(function($query){
                                                    return $query->orderBy('id','DESC');
                                                })->all();
            return response()->json($clientes, 200);

        }
        $this   ->theme->prependTitle(trans('cliente::cliente.names').' :: ');
        return $this->theme->of('cliente::admin.cliente.index')->render();
    }

    /**
     * Display cliente.
     *
     * @param Request $request
     * @param Model   $cliente
     *
     * @return Response
     */
    public function show(ClienteAdminWebRequest $request, Cliente $cliente)
    {
        if (!$cliente->exists) {
            return response()->view('cliente::admin.cliente.new', compact('cliente'));
        }

        Form::populate($cliente);
        return response()->view('cliente::admin.cliente.show', compact('cliente'));
    }

    /**
     * Show the form for creating a new cliente.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ClienteAdminWebRequest $request)
    {

        $cliente = $this->repository->newInstance([]);

        Form::populate($cliente);

        return response()->view('cliente::admin.cliente.create', compact('cliente'));

    }

    /**
     * Create new cliente.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ClienteAdminWebRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $cliente          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('cliente::cliente.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/cliente/cliente/'.$cliente->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show cliente for editing.
     *
     * @param Request $request
     * @param Model   $cliente
     *
     * @return Response
     */
    public function edit(ClienteAdminWebRequest $request, Cliente $cliente)
    {
        Form::populate($cliente);
        return  response()->view('cliente::admin.cliente.edit', compact('cliente'));
    }

    /**
     * Update the cliente.
     *
     * @param Request $request
     * @param Model   $cliente
     *
     * @return Response
     */
    public function update(ClienteAdminWebRequest $request, Cliente $cliente)
    {
        try {

            $attributes = $request->all();

            $cliente->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('cliente::cliente.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/cliente/cliente/'.$cliente->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/cliente/cliente/'.$cliente->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the cliente.
     *
     * @param Model   $cliente
     *
     * @return Response
     */
    public function destroy(ClienteAdminWebRequest $request, Cliente $cliente)
    {

        try {

            $t = $cliente->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('cliente::cliente.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/cliente/cliente/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/cliente/cliente/'.$cliente->getRouteKey()),
            ], 400);
        }
    }
}
