<?php

namespace Clientes\Cliente\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Clientes\Cliente\Models\Cliente;

class ClientePolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the cliente.
     *
     * @param User $user
     * @param Cliente $cliente
     *
     * @return bool
     */
    public function view(User $user, Cliente $cliente)
    {
        if ($user->canDo('cliente.cliente.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $cliente->user_id;
    }

    /**
     * Determine if the given user can create a cliente.
     *
     * @param User $user
     * @param Cliente $cliente
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('cliente.cliente.create');
    }

    /**
     * Determine if the given user can update the given cliente.
     *
     * @param User $user
     * @param Cliente $cliente
     *
     * @return bool
     */
    public function update(User $user, Cliente $cliente)
    {
        if ($user->canDo('cliente.cliente.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $cliente->user_id;
    }

    /**
     * Determine if the given user can delete the given cliente.
     *
     * @param User $user
     * @param Cliente $cliente
     *
     * @return bool
     */
    public function destroy(User $user, Cliente $cliente)
    {
        if ($user->canDo('cliente.cliente.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $cliente->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
