<?php

namespace Clientes\Cliente\Providers;

use Illuminate\Support\ServiceProvider;

class ClienteServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'cliente');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'cliente');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('cliente', function ($app) {
            return $this->app->make('Clientes\Cliente\Cliente');
        });

// Bind Cliente to repository
        $this->app->bind(
            \Clientes\Cliente\Interfaces\ClienteRepositoryInterface::class,
            \Clientes\Cliente\Repositories\Eloquent\ClienteRepository::class
        );
        // Bind Cliente to repository
        $this->app->bind(
            \Clientes\Cliente\Interfaces\ClienteRepositoryInterface::class,
            \Clientes\Cliente\Repositories\Eloquent\ClienteRepository::class
        );
        // Bind Arquivo to repository
        $this->app->bind(
            \Clientes\Cliente\Interfaces\ArquivoRepositoryInterface::class,
            \Clientes\Cliente\Repositories\Eloquent\ArquivoRepository::class
        );
        // Bind Pasta to repository
        $this->app->bind(
            \Clientes\Cliente\Interfaces\PastaRepositoryInterface::class,
            \Clientes\Cliente\Repositories\Eloquent\PastaRepository::class
        );
        // Bind Endereco to repository
        $this->app->bind(
            \Clientes\Cliente\Interfaces\EnderecoRepositoryInterface::class,
            \Clientes\Cliente\Repositories\Eloquent\EnderecoRepository::class
        );

        $this->app->register(\Clientes\Cliente\Providers\AuthServiceProvider::class);
        $this->app->register(\Clientes\Cliente\Providers\EventServiceProvider::class);
        $this->app->register(\Clientes\Cliente\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['cliente'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/cliente.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/cliente')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/cliente')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
